@@ -92,8 +92,6 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'action_plugins', action_plugins_path)
     config.set('defaults', 'lookup_plugins', lookups_path)
     config.set('defaults', 'filter_plugins', filter_plugins_path)
-    # suppress tasks if all hosts skip, was previously full_skip callback
-    config.set('defaults', 'display_skipped_hosts', 'no')
 
     log_path = os.path.join(work_dir, 'ansible.log')
     config.set('defaults', 'log_path', log_path)
@@ -110,7 +108,7 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'gathering', 'smart')
     config.set('defaults', 'fact_caching', 'jsonfile')
     config.set('defaults', 'fact_caching_connection',
-               '/var/tmp/ansible_fact_cache')
+               '/var/lib/mistral/ansible_fact_cache')
 
     # Expire facts in the fact cache after 7200s (2h)
     config.set('defaults', 'fact_caching_timeout', '7200')
@@ -187,12 +185,14 @@ class AnsibleAction(actions.Action):
         self.gather_facts = self._kwargs_for_run.pop('gather_facts', False)
 
         self._work_dir = None
+        self._remove_work_dir = False
 
     @property
     def work_dir(self):
         if self._work_dir:
             return self._work_dir
         self._work_dir = tempfile.mkdtemp(prefix='ansible-mistral-action')
+        self._remove_work_dir = True
         return self._work_dir
 
     @property
@@ -324,8 +324,13 @@ class AnsibleAction(actions.Action):
                     "log_path": os.path.join(self.work_dir, 'ansible.log')}
         finally:
             # NOTE(flaper87): clean the mess if debug is disabled.
-            if not self.verbosity:
-                shutil.rmtree(self.work_dir)
+            try:
+                if not self.verbosity and self._remove_work_dir:
+                    shutil.rmtree(self.work_dir)
+            except Exception as e:
+                msg = "An error happened while cleaning work directory: " + e
+                LOG.error(msg)
+                return actions.Result(error=msg)
 
 
 class AnsiblePlaybookAction(base.TripleOAction):
@@ -385,11 +390,14 @@ class AnsiblePlaybookAction(base.TripleOAction):
         self.command_timeout = self._kwargs_for_run.pop(
             'command_timeout', None)
 
+        self._remove_work_dir = False
+
     @property
     def work_dir(self):
         if self._work_dir:
             return self._work_dir
         self._work_dir = tempfile.mkdtemp(prefix='ansible-mistral-action')
+        self._remove_work_dir = True
         return self._work_dir
 
     @property
@@ -660,8 +668,13 @@ class AnsiblePlaybookAction(base.TripleOAction):
                     "log_path": os.path.join(self.work_dir, 'ansible.log')}
         finally:
             # NOTE(flaper87): clean the mess if debug is disabled.
-            if not self.verbosity:
-                shutil.rmtree(self.work_dir)
+            try:
+                if not self.verbosity and self._remove_work_dir:
+                    shutil.rmtree(self.work_dir)
+            except Exception as e:
+                msg = "An error happened while cleaning work directory: " + e
+                LOG.error(msg)
+                return actions.Result(error=msg)
 
 
 class AnsibleGenerateInventoryAction(base.TripleOAction):
