@@ -137,8 +137,6 @@ PASSWORD_PARAMETER_NAMES = (
     'SnmpdReadonlyUserPassword',
     'SwiftHashSuffix',
     'SwiftPassword',
-    'TackerPassword',
-    'TrovePassword',
     'ZaqarPassword',
 )
 # List of legacy resource names from overcloud.yaml
