@@ -36,12 +36,12 @@ from tripleo_common.tests.image import fakes
 
 filedata = six.u(
     """container_images:
-    - imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
+    - imagename: docker.io/tripleotrain/heat-docker-agents-centos:latest
       push_destination: localhost:8787
-    - imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
+    - imagename: docker.io/tripleotrain/centos-binary-nova-compute:liberty
       push_destination: localhost:8787
-    - imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
-    - imagename: docker.io/tripleomaster/image-with-missing-tag
+    - imagename: docker.io/tripleotrain/centos-binary-nova-libvirt:liberty
+    - imagename: docker.io/tripleotrain/image-with-missing-tag
       push_destination: localhost:8787
 """)
 
@@ -1260,10 +1260,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleotrain/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleotrain/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1280,9 +1280,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://docker.io/tripleomaster/'
+        source_url = urlparse('docker://docker.io/tripleotrain/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleomaster/'
+        target_url = urlparse('docker://localhost:8787/tripleotrain/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1318,8 +1318,7 @@ class TestPythonImageUploader(base.TestCase):
             source_session=source_session,
             target_session=target_session,
             source_layers=['sha256:aaa', 'sha256:bbb', 'sha256:ccc'],
-            multi_arch=False,
-            lock=None
+            multi_arch=False
         )
 
     @mock.patch('tripleo_common.image.image_uploader.'
@@ -1358,10 +1357,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleotrain/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleotrain/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1378,9 +1377,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://docker.io/tripleomaster/'
+        source_url = urlparse('docker://docker.io/tripleotrain/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleomaster/'
+        target_url = urlparse('docker://localhost:8787/tripleotrain/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1427,10 +1426,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = '192.0.2.0:8787/tripleomaster/heat-docker-agents-centos'
+        image = '192.0.2.0:8787/tripleotrain/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleotrain/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1447,9 +1446,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://192.0.2.0:8787/tripleomaster/'
+        source_url = urlparse('docker://192.0.2.0:8787/tripleotrain/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleomaster/'
+        target_url = urlparse('docker://localhost:8787/tripleotrain/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1495,10 +1494,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleotrain/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleotrain/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1515,9 +1514,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://docker.io/tripleomaster/'
+        source_url = urlparse('docker://docker.io/tripleotrain/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleomaster/'
+        target_url = urlparse('docker://localhost:8787/tripleotrain/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1553,8 +1552,7 @@ class TestPythonImageUploader(base.TestCase):
             source_session=source_session,
             target_session=target_session,
             source_layers=['sha256:aaa', 'sha256:bbb', 'sha256:ccc'],
-            multi_arch=False,
-            lock=None
+            multi_arch=False
         )
 
     @mock.patch('tripleo_common.image.image_uploader.'
@@ -1602,11 +1600,11 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleotrain/heat-docker-agents-centos'
         tag = 'latest'
         append_tag = 'modify-123'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleotrain/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1620,22 +1618,22 @@ class TestPythonImageUploader(base.TestCase):
         )
 
         source_url = urlparse(
-            'docker://docker.io/tripleomaster/'
+            'docker://docker.io/tripleotrain/'
             'heat-docker-agents-centos:latest')
         unmodified_target_url = urlparse(
-            'docker://localhost:8787/tripleomaster/'
+            'docker://localhost:8787/tripleotrain/'
             'heat-docker-agents-centos:latest')
         local_modified_url = urlparse(
-            'containers-storage:localhost:8787/tripleomaster/'
+            'containers-storage:localhost:8787/tripleotrain/'
             'heat-docker-agents-centos:latestmodify-123')
         target_url = urlparse(
-            'docker://localhost:8787/tripleomaster/'
+            'docker://localhost:8787/tripleotrain/'
             'heat-docker-agents-centos:latestmodify-123')
 
         self.assertEqual([
-            'localhost:8787/tripleomaster/'
+            'localhost:8787/tripleotrain/'
             'heat-docker-agents-centos:latest',
-            'localhost:8787/tripleomaster/'
+            'localhost:8787/tripleotrain/'
             'heat-docker-agents-centos:latestmodify-123'],
             self.uploader.upload_image(task)
         )
@@ -1685,16 +1683,15 @@ class TestPythonImageUploader(base.TestCase):
             source_session=source_session,
             target_session=target_session,
             source_layers=['sha256:aaa', 'sha256:bbb', 'sha256:ccc'],
-            multi_arch=False,
-            lock=None
+            multi_arch=False
         )
         _copy_registry_to_local.assert_called_once_with(unmodified_target_url)
         run_modify_playbook.assert_called_once_with(
             'add-foo-plugin',
             {'foo_version': '1.0.1'},
-            'localhost:8787/tripleomaster/'
+            'localhost:8787/tripleotrain/'
             'heat-docker-agents-centos:latest',
-            'localhost:8787/tripleomaster/'
+            'localhost:8787/tripleotrain/'
             'heat-docker-agents-centos:latest',
             'modify-123',
             container_build_tool='buildah'
@@ -1722,7 +1719,7 @@ class TestPythonImageUploader(base.TestCase):
             target_session
         ]
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleotrain/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
         source_image = 'containers-storage:%s:%s' % (image, tag)
@@ -1743,7 +1740,7 @@ class TestPythonImageUploader(base.TestCase):
             self.uploader.upload_image(task)
         )
         source_url = urlparse(source_image)
-        target_url = urlparse('docker://localhost:8787/tripleomaster/'
+        target_url = urlparse('docker://localhost:8787/tripleotrain/'
                               'heat-docker-agents-centos:latest')
         authenticate.assert_has_calls([
             mock.call(
@@ -1816,7 +1813,8 @@ class TestPythonImageUploader(base.TestCase):
 
     @mock.patch('tripleo_common.image.image_uploader.'
                 'PythonImageUploader._upload_url')
-    def test_copy_layer_registry_to_registry(self, _upload_url):
+    @mock.patch('tripleo_common.utils.image.uploaded_layers_details')
+    def test_copy_layer_registry_to_registry(self, global_check, _upload_url):
         _upload_url.return_value = 'https://192.168.2.1:5000/v2/upload'
         source_url = urlparse('docker://docker.io/t/nova-api:latest')
         target_url = urlparse('docker://192.168.2.1:5000/t/nova-api:latest')
@@ -1835,6 +1833,7 @@ class TestPythonImageUploader(base.TestCase):
         layer = layer_entry['digest']
 
         # layer already exists at destination
+        global_check.return_value = (None, None)
         self.requests.head(
             'https://192.168.2.1:5000/v2/t/nova-api/blobs/%s' % blob_digest,
             status_code=200
@@ -2022,8 +2021,9 @@ class TestPythonImageUploader(base.TestCase):
     @mock.patch('subprocess.Popen')
     @mock.patch('tripleo_common.image.image_uploader.'
                 'PythonImageUploader._upload_url')
-    def test_copy_layer_local_to_registry(self, _upload_url, mock_popen,
-                                          mock_exists):
+    @mock.patch('tripleo_common.utils.image.uploaded_layers_details')
+    def test_copy_layer_local_to_registry(self, global_check, _upload_url,
+                                          mock_popen, mock_exists):
         mock_exists.return_value = True
         _upload_url.return_value = 'https://192.168.2.1:5000/v2/upload'
         target_url = urlparse('docker://192.168.2.1:5000/t/nova-api:latest')
@@ -2048,6 +2048,7 @@ class TestPythonImageUploader(base.TestCase):
         }
 
         # layer already exists at destination
+        global_check.return_value = (None, None)
         self.requests.head(
             'https://192.168.2.1:5000/v2/t/'
             'nova-api/blobs/%s' % compressed_digest,
@@ -2117,6 +2118,7 @@ class TestPythonImageUploader(base.TestCase):
             layer
         )
 
+    @mock.patch('tripleo_common.utils.image.uploaded_layers_details')
     @mock.patch('tripleo_common.image.image_uploader.'
                 'PythonImageUploader._image_manifest_config')
     @mock.patch('tripleo_common.image.image_uploader.'
@@ -2127,11 +2129,12 @@ class TestPythonImageUploader(base.TestCase):
                 'PythonImageUploader._upload_url')
     def test_copy_local_to_registry(self, _upload_url, _containers_json,
                                     _copy_layer_local_to_registry,
-                                    _image_manifest_config):
+                                    _image_manifest_config, _global_check):
         source_url = urlparse('containers-storage:/t/nova-api:latest')
         target_url = urlparse('docker://192.168.2.1:5000/t/nova-api:latest')
         target_session = requests.Session()
         _upload_url.return_value = 'https://192.168.2.1:5000/v2/upload'
+        _global_check.return_value = (None, None)
         layers = [{
             "compressed-diff-digest": "sha256:aeb786",
             "compressed-size": 74703002,
@@ -2345,6 +2348,49 @@ class TestPythonImageUploader(base.TestCase):
             self.uploader._inspect(url)
         )
 
+    @mock.patch('tripleo_common.image.image_uploader.'
+                'PythonImageUploader._image_manifest_config')
+    def test_inspect_no_labels(self, _image_manifest_config):
+        url = urlparse('containers-storage:/t/nova-api:latest')
+        config = {
+            'config': {},
+            'architecture': 'x86_64',
+            'os': 'linux'
+        }
+        _image_manifest_config.return_value = (
+            {
+                'id': 'cccc',
+                'digest': 'sha256:ccccc',
+                'names': ['192.168.2.1:5000/t/nova-api:latest'],
+                'created': '2018-10-02T11:13:45.567533229Z'
+            }, {
+                'config': {
+                    'digest': 'sha256:1234',
+                },
+                'layers': [
+                    {'digest': 'sha256:aaa'},
+                    {'digest': 'sha256:bbb'},
+                    {'digest': 'sha256:ccc'}
+                ],
+            },
+            json.dumps(config)
+        )
+
+        self.assertEqual(
+            {
+                'Name': '/t/nova-api',
+                'Architecture': 'x86_64',
+                'Created': '2018-10-02T11:13:45.567533229Z',
+                'Digest': 'sha256:ccccc',
+                'DockerVersion': '',
+                'Labels': {},
+                'Layers': ['sha256:aaa', 'sha256:bbb', 'sha256:ccc'],
+                'Os': 'linux',
+                'RepoTags': []
+            },
+            self.uploader._inspect(url)
+        )
+
     @mock.patch('os.environ')
     @mock.patch('subprocess.Popen')
     def test_delete(self, mock_popen, mock_environ):
