@@ -17,6 +17,11 @@ from six.moves import urllib
 from tripleo_common import constants
 from tripleo_common.utils import common as common_utils
 
+try:  # py3
+    from shlex import quote
+except ImportError:  # py2
+    from pipes import quote
+
 
 def get_service_ips(stack):
     service_ips = {}
@@ -90,6 +95,7 @@ def create_overcloudrc(stack, no_proxy, admin_password, region_name):
         'OS_PASSWORD': admin_password,
         'OS_AUTH_URL': overcloud_endpoint.replace('/v2.0', ''),
         'OS_IDENTITY_API_VERSION': '3',
+        'OS_COMPUTE_API_VERSION': '2.latest',
         'OS_IMAGE_API_VERSION': constants.DEFAULT_IMAGE_API_VERSION,
         'OS_VOLUME_API_VERSION': constants.DEFAULT_VOLUME_API_VERSION,
         'OS_REGION_NAME': region_name or 'regionOne'
@@ -97,7 +103,8 @@ def create_overcloudrc(stack, no_proxy, admin_password, region_name):
 
     overcloudrc = CLEAR_ENV
     for key, value in rc_params.items():
-        line = "export %(key)s=%(value)s\n" % {'key': key, 'value': value}
+        line = "export %(key)s=%(value)s\n" % {'key': key,
+                                               'value': quote(value)}
         overcloudrc = overcloudrc + line
     overcloudrc = overcloudrc + CLOUDPROMPT
 
